@@ -15,7 +15,7 @@
 void
 Audio_staff::add_audio_item (Audio_item* l)
 {
-  audio_item_l_arr_.push (l);
+  audio_items_.push (l);
 }
 
 
@@ -23,8 +23,8 @@ void
 Audio_staff::output (Midi_stream& midi_stream_r, int track_i)
 {
   Midi_track midi_track;
-  midi_track.number_i_ = track_i;
-  midi_track.channel_i_ = channel_i_;
+  midi_track.number_ = track_i;
+  midi_track.channel_ = channel_;
   for (Midi_walker i (this, &midi_track); i.ok (); i++)
     i.process ();
   midi_stream_r << midi_track;
