@@ -40,8 +40,6 @@ private:
 };
 
 
-
-
 Text_spanner_engraver::Text_spanner_engraver ()
 {
   finished_ = 0;
@@ -146,7 +144,7 @@ Text_spanner_engraver::typeset_all ()
       if (!finished_->get_bound (RIGHT))
 	{
 	  Grob* e = unsmob_grob (get_property ("currentMusicalColumn"));
-	  span_->set_bound (RIGHT, e);
+	  finished_->set_bound (RIGHT, e);
 	}
       typeset_grob (finished_);
       finished_ = 0;
