@@ -4,7 +4,6 @@
 # * junk --outdir for --output
 # * Figure out clean set of options.
 # *
-# * EndLilyPondOutput is def'd as vfil. Causes large white gaps.
 # * texinfo: add support for @pagesize
 
 # todo: dimension handling (all the x2y) is clumsy. (tca: Thats
@@ -56,7 +55,18 @@ import __main__
 ## https://sourceforge.net/tracker/?func=detail&aid=604803&group_id=5470&atid=105470
 ##
 
-if float (sys.version[0:3]) <= 2.1 or sys.version[0:5] == '2.2.1':
+
+##
+##
+##
+
+
+
+
+if float (sys.version[0:3]) <= 2.1: 
+## or sys.version[0:5] == '2.2.1':
+## still broken on python 2.2.1  / RH8.
+	
 	try:
 		import pre
 		re = pre
@@ -79,7 +89,7 @@ errorport = sys.stderr
 verbose_p = 0
 
 
-
+localedir = '@localedir@'
 try:
 	import gettext
 	gettext.bindtextdomain ('lilypond', localedir)
@@ -159,6 +169,7 @@ g_force_music_fontsize = 0
 g_read_lys = 0
 g_do_pictures = 1
 g_do_music = 1
+g_make_html = 0
 
 format = ''
 g_run_lilypond = 1
@@ -319,7 +330,7 @@ html_linewidths = {
 	'letterpaper': {12: in2pt(6)}}
 
 option_definitions = [
-	('EXT', 'f', 'format', 'use output format EXT (texi [default], latex, html)'),
+	('EXT', 'f', 'format', 'use output format EXT (texi [default], texi-html, latex, html)'),
 	('DIM',  '', 'default-music-fontsize', 'default fontsize for music.  DIM is assumed to be in points'),
 	('DIM',  '', 'default-lilypond-fontsize', 'deprecated, use --default-music-fontsize'),
 	('OPT', '', 'extra-options' , 'pass OPT quoted to the lilypond command line'),
@@ -411,7 +422,13 @@ output_dict= {
 		'output-noinline': r'''
 %% generated: %(fn)s.eps
 ''',
-		'output-tex': '{\\preLilypondExample \\input %(fn)s.tex \\postLilypondExample\n}',
+		'output-latex-quoted': r'''{\preLilypondExample
+\input %(fn)s.tex
+\postLilypondExample}''',
+		'output-latex-noquote': r'''{\parindent 0pt
+\preLilypondExample
+\input %(fn)s.tex
+\postLilypondExample}''',
 		'pagebreak': r'\pagebreak',
 		},
 
@@ -445,16 +462,12 @@ output_dict= {
 %s@end example
 ''',
 		# do some tweaking: @ is needed in some ps stuff.
-		# override EndLilyPondOutput, since @tex is done
-		# in a sandbox, you can't do \input lilyponddefs at the
-		# top of the document.
 		#
 		# ugh, the <p> below breaks inline images...
 		'output-texi-noquote': r'''@tex
 \catcode`\@=12
 \parindent 0pt
-\input lilyponddefs
-\def\EndLilyPondOutput{}
+\def\lilypondbook{}
 \input %(fn)s.tex
 \catcode`\@=0
 @end tex
@@ -467,8 +480,7 @@ output_dict= {
 		'output-texi-quoted': r'''@quotation
 @tex
 \catcode`\@=12
-\input lilyponddefs
-\def\EndLilyPondOutput{}
+\def\lilypondbook{}
 \input %(fn)s.tex
 \catcode`\@=0
 @end tex
@@ -1028,7 +1040,7 @@ def schedule_lilypond_block (chunk):
 		update_file(file_body, os.path.join(g_outdir, basename) + '.ly')
 	needed_filetypes = ['tex']
 
-	if format == 'html' or format == 'texi':
+	if format == 'html' or g_make_html:
 		needed_filetypes.append ('eps')
 		needed_filetypes.append ('png')
 	if 'eps' in opts and not ('eps' in needed_filetypes):
@@ -1080,7 +1092,10 @@ def schedule_lilypond_block (chunk):
 		if 'eps' in opts:
 			s = 'output-eps'
 		else:
-			s = 'output-tex'
+			if 'noquote' in opts:
+				s = 'output-latex-noquote'
+			else:
+				s = 'output-latex-quoted'
 	elif format == 'texi':
 		if 'noquote' in opts:
 			s = 'output-texi-noquote'
@@ -1483,6 +1498,9 @@ for opt in options:
 		__main__.verbose_p = 1
 	elif o == '--format' or o == '-f':
 		__main__.format = a
+		if a == 'texi-html':
+			__main__.format = 'texi'
+			g_make_html = 1
 	elif o == '--outname' or o == '-o':
 		if len(files) > 1:
 			#HACK
